From 0fd51fc5d7a9d16264dc0f4c8cb0ef6923649f03 Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Thu, 09 Jul 2009 05:48:08 -0400
Subject: [PATCH] Fixed: FS#786 - Client with enables client module cannot choose a client when adding a dns zone Fixed: FS#787 - A sub-client can see all the clients on the system in the client drop down list 

---
 interface/web/client/client_list.php |   48 ++++++++++++++++++++++++------------------------
 1 files changed, 24 insertions(+), 24 deletions(-)

diff --git a/interface/web/client/client_list.php b/interface/web/client/client_list.php
index 49cecb9..590da21 100644
--- a/interface/web/client/client_list.php
+++ b/interface/web/client/client_list.php
@@ -1,25 +1,25 @@
-<?php
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
-
-/******************************************
-* Begin Form configuration
-******************************************/
-
-$list_def_file = "list/reseller.list.php";
-
-/******************************************
-* End Form configuration
-******************************************/
-
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],$_SESSION["s"]["module"]["name"])) {
-	header("Location: ../index.php");
-	exit;
-}
-
-$app->uses('listform_actions');
-$app->listform_actions->onLoad();
-
-
+<?php
+require_once('../../lib/config.inc.php');
+require_once('../../lib/app.inc.php');
+
+/******************************************
+* Begin Form configuration
+******************************************/
+
+$list_def_file = "list/client.list.php";
+
+/******************************************
+* End Form configuration
+******************************************/
+
+//* Check permissions for module
+$app->auth->check_module_permissions('client');
+
+$app->uses('listform_actions');
+
+$app->listform_actions->SQLOrderBy = 'ORDER BY company_name, contact_name, client_id';
+$app->listform_actions->SQLExtWhere = "limit_client = 0";
+$app->listform_actions->onLoad();
+
+
 ?>
\ No newline at end of file

--
Gitblit v1.9.1